@@ -89,14 +89,26 @@ def _run_nested(fqdn_image, environment, command, interactive, name, net, volume
 
 def handle_volumes_bind_mount(docker_cmd, homedir, volumes, workspace):
     volumes = volumes or []
-    volumes.extend([
-        '%(workspace)s:%(workspace)s:rw,Z' % dict(workspace=workspace),
-        '%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=homedir),
-        '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=homedir),
-        '/var/lib/osmosis:/var/lib/osmosis:rw,Z',
-        '/var/run/docker.sock:/var/run/docker.sock:Z',
-        '/opt/skipper/skipper-entrypoint.sh:/opt/skipper/skipper-entrypoint.sh:Z',
-    ])
+    volumes.extend(['%(homedir)s/.netrc:%(homedir)s/.netrc:ro' % dict(homedir=homedir),
+                    '%(homedir)s/.gitconfig:%(homedir)s/.gitconfig:ro' % dict(homedir=homedir)])
+
+    if utils.get_runtime_command() == utils.PODMAN:
+        volumes.extend([
+            '%(workspace)s:%(workspace)s:rw,shared' % dict(workspace=workspace),
+            '%s:/opt/skipper/skipper-entrypoint.sh:rw' % utils.get_extra_file("skipper-entrypoint.sh"),
+        ])
+        if os.path.exists('/var/run/docker.sock'):
+            volumes.append('/var/run/docker.sock:/var/run/docker.sock:rw')
+        if os.path.exists('/var/lib/osmosis'):
+            volumes.append('/var/lib/osmosis:/var/lib/osmosis:rw')
+    else:
+        volumes.extend([
+            '%(workspace)s:%(workspace)s:rw,Z' % dict(workspace=workspace),
+            '/var/lib/osmosis:/var/lib/osmosis:rw,Z',
+            '/var/run/docker.sock:/var/run/docker.sock:Z',
+            '%s:/opt/skipper/skipper-entrypoint.sh:Z' % utils.get_extra_file("skipper-entrypoint.sh"),
+            ])
+
     for volume in volumes:
         if ":" not in volume:
             raise ValueError("Volume entry is badly-formatted - %s" % volume)
@@ -106,27 +118,46 @@ def handle_volumes_bind_mount(docker_cmd, homedir, volumes, workspace):
             if volume.startswith('/etc/') or volume.startswith('/var/lib/'):
                 volume = '/private' + volume
 
+        # if part of host directory is empty, skipping this mount
+        if not volume.split(":")[0]:
+            continue
+
+        create_vol_localpath_if_needed(volume)
+        docker_cmd += ['-v', volume]
+
+    return docker_cmd
+
+
+def create_vol_localpath_if_needed(volume):
+    host_path = volume.split(":")[0].strip()
+    # We have couple of special case mounts
+    # 1. gitconfig file - it is required by skipper but may not exists, we don't want
+    # to create folder if it doesn't exist
+    # that's why we create it as file
+    # 2. .docker/config.json - if it is required and doesn't exists we want to create is as file with {} as data
+    if ".gitconfig" in host_path and not os.path.exists(host_path):
+        utils.create_path_and_add_data(host_path, data="", is_file=True)
+    elif "docker/config.json" in host_path and not os.path.exists(host_path):
+        utils.create_path_and_add_data(host_path, data="{}", is_file=True)
+    elif not os.path.exists(host_path):
         # If the local directory of a mount entry doesn't exist, docker will by
         # default create a directory in that path. Docker runs in systemd context,
         # with root-privileges, so the container will have no permissions to write
         # to that directory. To prevent that, we'll create the directory in advance,
         # with the user's permissions
-        localdir = volume.split(":")[0]
-        if not os.path.exists(localdir.strip()):
-            try:
-                os.makedirs(localdir)
-            except OSError:
-                # If we have no permissions to create the directory, we'll just let
-                # docker create it with root-privileges
-                pass
-
-        docker_cmd += ['-v', volume]
-    return docker_cmd
+        try:
+            os.makedirs(host_path)
+        except OSError:
+            # If we have no permissions to create the directory, we'll just let
+            # docker create it with root-privileges
+            pass
 
 
 @contextmanager
 def _network(net):
-    if _network_exists(net):
+    if utils.get_runtime_command() != "docker":
+        yield
+    elif _network_exists(net):
         yield
     else:
         _create_network(net)
@@ -146,10 +177,6 @@ def _destroy_network(net):
 
 
 def _network_exists(net):
-    cmd = ['network', 'ls']
-    if utils.get_runtime_command() == "docker":
-        cmd.extend(["-f", "NAME=%s" % net])
-    else:
-        cmd.append("-q")
+    cmd = ['network', 'ls', "-f", "NAME=%s" % net]
     result = utils.run_container_command(cmd)
     return net in result
