@@ -7,6 +7,7 @@ from distutils.spawn import find_executable
 from six.moves import http_client
 import requests
 import urllib3
+import pkg_resources
 
 
 REGISTRY_BASE_URL = 'https://%(registry)s/v2/'
@@ -160,7 +161,20 @@ def get_runtime_command():
     return CONTAINER_RUNTIME_COMMAND
 
 
+def get_extra_file(filename):
+    return pkg_resources.resource_filename("skipper", "data/%s" % filename)
+
+
 def run_container_command(args):
     cmd = [get_runtime_command()]
     cmd.extend(args)
     return str(subprocess.check_output(cmd).decode().strip())
+
+
+def create_path_and_add_data(full_path, data, is_file):
+    directory = os.path.dirname(full_path)
+    if not os.path.exists(directory):
+        os.makedirs(directory)
+    if is_file:
+        with open(full_path, "w") as _file:
+            _file.write(data)
